@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2001-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -118,7 +118,7 @@ static ztimer_t zen_ztimer = ZTIMER_INITIALIZER;
 #define ZenTimerReport(oper) G_STMT_START {                            \
 	if (zen_ztimer.stop.msec < zen_ztimer.start.msec) {            \
 		zen_ztimer.stop.msec += 1000;                          \
-		zen_ztimer.stop.sec -= 1;                              \
+		zen_ztimer.stop.sec--;                                 \
 	}                                                              \
 	                                                               \
 	fprintf (stderr, "ZenTimer: %s took %lu.%03d seconds\n", oper, \
